@@ -18,17 +18,19 @@ from typing import (
     AsyncIterator,
     Awaitable,
     Callable,
+    Iterator,
+    Optional,
     Sequence,
     Tuple,
-    Optional,
-    Iterator,
 )
 
-from google.cloud.artifactregistry_v1beta2.types import file
-from google.cloud.artifactregistry_v1beta2.types import package
-from google.cloud.artifactregistry_v1beta2.types import repository
-from google.cloud.artifactregistry_v1beta2.types import tag
-from google.cloud.artifactregistry_v1beta2.types import version
+from google.cloud.artifactregistry_v1beta2.types import (
+    file,
+    package,
+    repository,
+    tag,
+    version,
+)
 
 
 class ListRepositoriesPager:
